%define major		18
%define libname		%mklibname %{name} %{major}
%define develname	%mklibname %{name} -d

%define url_ver		%(echo %{version}|sed -e 's/\\.//g')

Name:		dcmtk
Version:	3.6.8
Release:	%mkrel 2
Summary:	DICOM Toolkit libraries and applications
Group:		System/Libraries
License:	BSD and MIT
URL:		https://dicom.offis.de/dcmtk.php.en
Source0:	ftp://dicom.offis.de/pub/dicom/offis/software/dcmtk/dcmtk%{url_ver}/%{name}-%{version}.tar.gz
# Upstream fixes
Patch1:		0001-Fixed-buffer-overflow-in-decompression-codecs.patch
Patch2:		0001-Fixed-possible-overflows-when-allocating-memory.patch
# CVE-2024-34508 and CVE-2024-34509 (P3)
Patch3:		0001-Fixed-two-segmentation-faults.patch
Patch4:		0001-Fixed-unchecked-typecasts-of-DcmItem-search-results.patch
# CVE-2024-28130 (P5)
Patch5:		0002-Fixed-unchecked-typecasts-and-fixed-LUT-handling.patch
Patch6:		0003-Fixed-wrong-error-handling-previous-commit.patch
Patch7:		0001-Fixed-DcmDecimalString-unit-tests.patch

BuildRequires:	cmake
BuildRequires:	bison
BuildRequires:	doxygen
BuildRequires:	flex
BuildRequires:	charls-devel
BuildRequires:	wrap-devel
BuildRequires:	pkgconfig(icu-uc)
BuildRequires:	pkgconfig(libjpeg)
BuildRequires:	pkgconfig(libopenjp2)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(libtiff-4)
BuildRequires:	pkgconfig(libxml-2.0)
BuildRequires:	pkgconfig(openssl)
BuildRequires:	pkgconfig(sndfile)
BuildRequires:	pkgconfig(zlib)
# for xxd tool
BuildRequires:	vim-common

%description
DCMTK is a collection of libraries and applications implementing large parts
the DICOM standard. It includes software for examining, constructing
and converting DICOM image files, handling offline media, sending and receiving
images over a network connection, as well as demonstrative image storage
and worklist servers. DCMTK is is written in a mixture of ANSI C and C++.
It comes in complete source code and is made available as "open source"
software.

DCMTK has been used at numerous DICOM demonstrations to provide central,
vendor-independent image storage and worklist servers (CTNs - Central Test
Nodes). It is used by hospitals and companies all over the world for a wide
variety of purposes ranging from being a tool for product testing to being
a building block for research projects, prototypes and commercial products.

%package -n	%{libname}
Summary:	DICOM Toolkit libraries
Group:		System/Libraries

%description -n	%{libname}
DCMTK is a collection of libraries and applications implementing large parts
the DICOM standard. It includes software for examining, constructing
and converting DICOM image files, handling offline media, sending and receiving
images over a network connection, as well as demonstrative image storage
and worklist servers. DCMTK is is written in a mixture of ANSI C and C++.
It comes in complete source code and is made available as "open source"
software.

This package contains shared libraries.

%package -n	%{develname}
Summary:	DICOM Toolkit libraries development files
Group:		Development/C
Requires:	%{name} = %{version}
Requires:	%{libname} = %{version}
Provides:	%{name}-devel = %{version}-%{release}

%description -n	%{develname}
DCMTK is a collection of libraries and applications implementing large parts
the DICOM standard. It includes software for examining, constructing
and converting DICOM image files, handling offline media, sending and receiving
images over a network connection, as well as demonstrative image storage
and worklist servers. DCMTK is is written in a mixture of ANSI C and C++.
It comes in complete source code and is made available as "open source"
software.

This package contains files required for development only.

%prep
%autosetup -p1

%build
%cmake \
	-DDCMTK_INSTALL_CMKDIR=%{_libdir}/cmake/%{name} \
	-DDCMTK_WITH_XML=ON \
	-DDCMTK_WITH_OPENSSL=ON \
	-DDCMTK_WITH_SNDFILE=ON \
	-DDCMTK_WITH_ZLIB=ON

%cmake_build

%install
%cmake_install

%files
%doc %{_defaultdocdir}/%{name}-%{version}/
%dir %{_sysconfdir}/%{name}-%{version}
%config(noreplace) %{_sysconfdir}/%{name}-%{version}/*.cfg
%{_bindir}/*
%{_datadir}/%{name}-%{version}/
%{_mandir}/man1/*

%files -n %{libname}
%{_libdir}/*.so.%{major}{,.*}

%files -n %{develname}
%{_includedir}/%{name}/
%{_libdir}/*.so
%{_libdir}/cmake/%{name}/
%{_libdir}/pkgconfig/dcmtk.pc


%changelog
* Tue Jul 02 2024 daviddavid <daviddavid> 3.6.8-2.mga10
+ Revision: 2078765
- backport upstream patches to fix CVE-2024-28130 and CVE-2024-3450[89] (mga#33350)

* Sun Jan 14 2024 daviddavid <daviddavid> 3.6.8-1.mga10
+ Revision: 2031209
- new version: 3.6.8
- remove merged upstream patches

* Wed Sep 27 2023 tv <tv> 3.6.7-5.mga10
+ Revision: 1991349
- Rebuild for icu-73

* Tue Mar 07 2023 daviddavid <daviddavid> 3.6.7-4.mga9
+ Revision: 1947958
- add upstream patch to fix CVE-2022-43272 (mga#30790)

* Sat Jan 07 2023 squidf <squidf> 3.6.7-3.mga9
+ Revision: 1931110
- Mass rebuild for icu 72.1

* Mon Dec 12 2022 ns80 <ns80> 3.6.7-2.mga9
+ Revision: 1920982
- rebuild for new libtiff

* Tue Sep 13 2022 neoclust <neoclust> 3.6.7-1.mga9
+ Revision: 1887567
- New version 	3.6.7

* Sat Jun 18 2022 squidf <squidf> 3.6.6-5.mga9
+ Revision: 1864846
- rebuild for icu 71.1

* Tue Mar 29 2022 umeabot <umeabot> 3.6.6-4.mga9
+ Revision: 1831624
- Mageia 9 Mass Rebuild

* Sat Oct 02 2021 wally <wally> 3.6.6-3.mga9
+ Revision: 1748044
- rebuild for openssl 3.0.0

* Wed Aug 04 2021 luigiwalser <luigiwalser> 3.6.6-2.mga9
+ Revision: 1739334
- rebuild for icu

* Mon Apr 26 2021 daviddavid <daviddavid> 3.6.6-1.mga9
+ Revision: 1719817
- new version: 3.6.6
- now libmajor is 16

* Tue Oct 27 2020 daviddavid <daviddavid> 3.6.5-3.mga8
+ Revision: 1639767
- add opensuse patch to avoid file conflict between dcmtk and charls

* Mon Feb 17 2020 umeabot <umeabot> 3.6.5-2.mga8
+ Revision: 1537403
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Thu Oct 31 2019 daviddavid <daviddavid> 3.6.5-1.mga8
+ Revision: 1457066
- new version: 3.6.5
- now libmajor is 15

* Sun Jan 06 2019 daviddavid <daviddavid> 3.6.4-1.mga7
+ Revision: 1350026
- new version: 3.6.4

* Sun Sep 23 2018 umeabot <umeabot> 3.6.3-2.mga7
+ Revision: 1297418
- Mageia 7 Mass Rebuild

* Tue May 01 2018 daviddavid <daviddavid> 3.6.3-1.mga7
+ Revision: 1224118
- new version: 3.6.3
- libify pkg as it should
+ dmorgan <dmorgan>
- Fix cmake and Buildrequires
- Fix build in x86_64
+ gil <gil>
- used pkgconfig
- imported package dcmtk


* Wed Jul 13 2011 gil <gil> 3.6.0-0.%%mkrel
- initial rpm
